'use strict';

Object.defineProperty(exports, '__esModule', {
  value: true
});

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var _videoJs = require('video.js');

var _videoJs2 = _interopRequireDefault(_videoJs);

// Default options for the plugin.
var defaults = {};

var addReplayClass = function addReplayClass(player) {
  if (player.duration() !== Infinity) {
    player.addClass('vjs-replay').getChild('controlBar').getChild('playToggle').controlText(player.localize('Replay'));
  }
};

var removeReplayClass = function removeReplayClass(player) {
  var controlLabel = undefined;

  if (!player.hasClass('vjs-replay')) {
    return;
  }

  // Reset the control's label
  if (player.paused()) {
    controlLabel = player.localize('Play');
  } else {
    controlLabel = player.localize('Pause');
  }
  player.removeClass('vjs-replay').getChild('controlBar').getChild('playToggle').controlText(controlLabel);
};

/**
 * Function to invoke when the player is ready.
 *
 * This is a great place for your plugin to initialize itself. When this
 * function is called, the player will have its DOM and child components
 * in place.
 *
 * @function onPlayerReady
 * @param    {Player} player
 * @param    {Object} [options={}]
 */
var onPlayerReady = function onPlayerReady(player, options) {
  player.on('ended', function () {
    addReplayClass(player);
  });
  player.on('play', function () {
    removeReplayClass(player);
  });
  player.on('seeking', function () {
    removeReplayClass(player);
  });
};

/**
 * A video.js plugin.
 *
 * In the plugin function, the value of `this` is a video.js `Player`
 * instance. You cannot rely on the player being in a "ready" state here,
 * depending on how the plugin is invoked. This may or may not be important
 * to you; if not, remove the wait for "ready"!
 *
 * @function replayButton
 * @param    {Object} [options={}]
 *           An object of options left to the plugin author to define.
 */
var replayButton = function replayButton(options) {
  var _this = this;

  this.ready(function () {
    onPlayerReady(_this, _videoJs2['default'].mergeOptions(defaults, options));
  });
};

// Register the plugin with video.js.
_videoJs2['default'].plugin('replayButton', replayButton);

// Include the version number.
replayButton.VERSION = '__VERSION__';

exports['default'] = replayButton;
module.exports = exports['default'];